@@ -34,10 +34,16 @@
 #include "dbuttonlist.h"
 #include "doptionlist.h"
 
-
-
 DWIDGET_BEGIN_NAMESPACE
 
+/*!
+ * \class DSettingsDialog
+ * \brief DSettingsDialog provide an common setting ui for deepin style application.
+ * It's depend Dtk::Widget::DSettingsWidgetFactory to auot build ui compent from json file.
+ * \sa Dtk::Widget::DSettingsWidgetFactory
+ * \sa Dtk::Core::DSettings
+ */
+
 class DSettingsDialogPrivate
 {
 public:
@@ -53,9 +59,8 @@ public:
     Q_DECLARE_PUBLIC(DSettingsDialog)
 };
 
-
 DSettingsDialog::DSettingsDialog(QWidget *parent) :
-    DAbstractDialog(parent), d_ptr(new DSettingsDialogPrivate(this))
+    DAbstractDialog(parent), dd_ptr(new DSettingsDialogPrivate(this))
 {
     Q_D(DSettingsDialog);
 
@@ -75,7 +80,7 @@ DSettingsDialog::DSettingsDialog(QWidget *parent) :
     d->rightFrame = new QFrame;
     d->rightFrame->setObjectName("RightFrame");
     d->rightLayout = new QVBoxLayout(d->rightFrame);
-    d->rightLayout->setContentsMargins(1, 5, 5, 0);
+    d->rightLayout->setContentsMargins(1, 0, 0, 0);
     d->rightLayout->setSpacing(0);
 
     d->content = new Content;
@@ -89,7 +94,11 @@ DSettingsDialog::DSettingsDialog(QWidget *parent) :
     setFixedWidth(680);
 
     connect(d->leftFrame, &Navigation::selectedGroup, d->content, &Content::onScrollToGroup);
-    connect(d->content, &Content::scrollToGroup, d->leftFrame, &Navigation::onSelectGroup);
+    connect(d->content, &Content::scrollToGroup, d->leftFrame, [ = ](const QString & key) {
+        d->leftFrame->blockSignals(true);
+        d->leftFrame->onSelectGroup(key);
+        d->leftFrame->blockSignals(false);
+    });
     connect(closeBt, &DWindowCloseButton::clicked, this, &DSettingsDialog::close);
 }
 
@@ -98,17 +107,33 @@ DSettingsDialog::~DSettingsDialog()
 
 }
 
+/*!
+ * \brief DSettingsDialog::widgetFactory return the widget build factory of this dialog.
+ * Every instance of DSettingDialog has it own widgetfactory.
+ * \return
+ */
 DSettingsWidgetFactory *DSettingsDialog::widgetFactory() const
 {
     Q_D(const DSettingsDialog);
     return  d->content->widgetFactory();
 }
 
+/*!
+ * \brief DSettingsDialog::updateSettings will create all widget for settings options.
+ * Warnning that you can only call the once.
+ * \param settings Dtk::Core::DSettings object from json
+ */
 void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
 {
     updateSettings(QByteArray(), settings);
 }
 
+/*!
+ * \brief DSettingsDialog::updateSettings
+ * \param translateContext is them custom translate data for i18n.
+ * \param settings Dtk::Core::DSettings object from json
+ * \sa void DSettingsDialog::updateSettings(Dtk::Core::DSettings *settings)
+ */
 void DSettingsDialog::updateSettings(const QByteArray &translateContext, Core::DSettings *settings)
 {
     Q_D(DSettingsDialog);
